@@ -1,5 +1,5 @@
 #
-# $Id: Unicode.pm,v 1.1 2001/05/15 19:34:29 dankogai Exp dankogai $
+# $Id: Unicode.pm,v 2.0 2005/05/16 19:08:12 dankogai Exp dankogai $
 #
 
 package Jcode::Unicode;
@@ -7,8 +7,8 @@ package Jcode::Unicode;
 use strict;
 use vars qw($RCSID $VERSION @ISA @EXPORT $PEDANTIC);
 
-$RCSID = q$Id: Unicode.pm,v 1.1 2001/05/15 19:34:29 dankogai Exp dankogai $;
-$VERSION = do { my @r = (q$Revision: 1.1 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
+$RCSID = q$Id: Unicode.pm,v 2.0 2005/05/16 19:08:12 dankogai Exp dankogai $;
+$VERSION = do { my @r = (q$Revision: 2.0 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
 
 use Carp;
 require Exporter;
@@ -20,60 +20,48 @@ $PEDANTIC ||= 0;
 
 bootstrap Jcode::Unicode $VERSION;
 
-sub _mkbuf{
-    my $thingy = shift;
-    if (ref $thingy){
-        return $thingy;
-    }
-    else{
-        my $buf = $thingy;
-        return \$buf;
-    }
-}
-
 # Merge these subs to Jcode
 
-sub Jcode::ucs2_euc{
-    my ($thingy, $pedantic) = @_; $pedantic ||= 0;
-    my $r_str = _mkbuf($thingy);
+sub Jcode::_Classic::ucs2_euc{
+    my ($thingy) = @_;
+    my $r_str = ref $thingy ? $thingy : \$thingy;
     return
-        $$r_str = Jcode::Unicode::ucs2_euc($$r_str, $pedantic);
+        $$r_str = Jcode::Unicode::ucs2_euc($$r_str);
 }
 
-sub Jcode::euc_ucs2{
-    my ($thingy, $pedantic) = @_; $pedantic ||= 0;
-    my $r_str = _mkbuf($thingy);
+sub Jcode::_Classic::euc_ucs2{
+    my ($thingy) = @_;
+    my $r_str = ref $thingy ? $thingy : \$thingy;
     return
-        $$r_str = Jcode::Unicode::euc_ucs2($$r_str, $pedantic);
+        $$r_str = Jcode::Unicode::euc_ucs2($$r_str);
 }
 
-sub Jcode::ucs2_utf8{
-    my ($thingy, $pedantic) = @_;
-    my $r_str = _mkbuf($thingy);
+sub Jcode::_Classic::ucs2_utf8{
+    my ($thingy) = @_;
+    my $r_str = ref $thingy ? $thingy : \$thingy;
     return
         $$r_str = Jcode::Unicode::ucs2_utf8($$r_str);
 }
 
-sub Jcode::utf8_ucs2{
+sub Jcode::_Classic::utf8_ucs2{
     my ($thingy) = @_;
-    my $r_str = _mkbuf($thingy);
+        my $r_str = ref $thingy ? $thingy : \$thingy;
     return
         $$r_str = Jcode::Unicode::utf8_ucs2($$r_str);
 }
 
-
-sub Jcode::euc_utf8{
-    my $thingy = shift;
-    my $r_str = _mkbuf($thingy);
-    &Jcode::euc_ucs2($r_str);
-    &Jcode::ucs2_utf8($r_str);
+sub Jcode::_Classic::euc_utf8{
+    my ($thingy) = @_;
+    my $r_str = ref $thingy ? $thingy : \$thingy;
+    return
+        $$r_str = Jcode::Unicode::euc_utf8($$r_str);
 }
 
-sub Jcode::utf8_euc{
-    my $thingy = shift;
-    my $r_str = _mkbuf($thingy);
-    &Jcode::utf8_ucs2($r_str);
-    &Jcode::ucs2_euc($r_str);
+sub Jcode::_Classic::utf8_euc{
+    my ($thingy) = @_;
+        my $r_str = ref $thingy ? $thingy : \$thingy;
+    return
+        $$r_str = Jcode::Unicode::utf8_euc($$r_str);
 }
 
 1;
@@ -95,6 +83,8 @@ This module is called by Jcode.pm on demand.  This module is not intended for
 direct use by users.  This modules implements functions related to Unicode.  
 Following functions are defined here;
 
+=over 4
+
 =item Jcode::ucs2_euc();
 
 =item Jcode::euc_ucs2();
@@ -107,18 +97,30 @@ Following functions are defined here;
 
 =item Jcode::utf8_euc();
 
+=back
+
 =cut
 
 =head1 VARIABLES
 
+=over 4
+
 =item B<$Jcode::Unicode::PEDANTIC>
 
+Now obsolete and abolished.  It used to mean..
+
 When set to non-zero, x-to-unicode conversion becomes pedantic.  
 That is, '\' (chr(0x5c)) is converted to zenkaku backslash and 
 '~" (chr(0x7e)) to JIS-x0212 tilde.
 
 By Default, Jcode::Unicode leaves ascii ([0x00-0x7f]) as it is.
 
+But as of perl 5.8.  It has been standarlized (in perl community)
+that we leave ascii as it is so Jcode no longer has to support
+this option.
+
+=back
+
 =cut
 
 =head1 BUGS
@@ -127,11 +129,12 @@ If any, that is Unicode, Inc. to Blame (Especially JIS0201.TXT).
 
 =head1 SEE ALSO
 
-=item http://www.unicode.org/
+L<http://www.unicode.org/>
+L<http://www.debian.or.jp/~kubota/unicode-symbols.html.en>
 
 =head1 COPYRIGHT
 
-Copyright 1999 Dan Kogai <dankogai@dan.co.jp>
+Copyright 1999-2003 Dan Kogai <dankogai@dan.co.jp>
 
 This library is free software; you can redistribute it
 and/or modify it under the same terms as Perl itself.
